@@ -2,6 +2,7 @@ import subprocess
 import re
 import os 
 import sys
+import html2text 
 import logging
 import collections
 from pyblog.colored_print import printDebug
@@ -16,11 +17,11 @@ try:
             , stdin=subprocess.PIPE
             )
 except OSError:
-    printDebug("INFO", "Pandoc not found")
+    logging.debug("Pandoc not found")
     panDoc = False
     
 if not panDoc:
-    import html2text as html2text
+    import text.html2text as html2text
     import markdown 
 
 def decodeText(text):
@@ -59,7 +60,7 @@ def htmlToMarkdown(content, convertor='pandoc'):
     global panDoc
     global pandocFmt
     if panDoc and convertor == 'pandoc':
-        logging.debug("using pandoc for html -> markdown")
+        printDebug("INFO", "Using pandoc for html -> markdown")
         cmd = ["pandoc", "-t", 'markdown'+pandocFmt, "-f", "html"]
         p = subprocess.Popen(cmd
                 , stdin = subprocess.PIPE
