@@ -69,10 +69,9 @@ def main():
         printDebug("INFO", "Wordpress `{}`".format(args.blogName))
         wpObj = Wordpress(args)
     else:
-        printDebug("WARN", "It does not look like a wordpress: {}".format(
-                args.server
+        printDebug("WARN"
+                , "It does not look like a wordpress: {}".format(args.server)
                 )
-            )
 
 
 if __name__ == "__main__":
