@@ -211,6 +211,15 @@ class Wordpress:
     def writeContent(self, fH, content, format):
         """Write content to file.
         """
+        newContent = ["<p>"]
+        for line in content.split('\n'):
+            if len(line.strip()) == 0:
+                newContent.append("</p>\n<p>")
+            else:
+                newContent.append(line)
+        newContent.append('<\p>')
+        content = '\n'.join(newContent)
+
         if format == "html":
             logging.info("Writing html content")
             content = formatter.htmlToHtml(content) 
@@ -232,12 +241,9 @@ class Wordpress:
         assert int(post.id.strip()) > 0, "Post must have an id"
 
         title = post.title.encode('utf-8')
-        terms = post.terms
-        logging.debug("Downloading : {0}".format(title))
-        printDebug("INFO", "Downloading {0}".format(post.post_type)
-                , title
-                )
+        printDebug("POST", "Downloading: `{}`".format(title))
 
+        terms = post.terms
         content = post.content.encode('utf-8')
         postDir = formatter.titleToFilePath(title, self.blogDir)
 
@@ -247,11 +253,11 @@ class Wordpress:
 
         # Good now for this post, we have directory. Download its content in
         # content.md file.
-        fileName = os.path.join(postDir, 'content.md')
+        fileMarkDown = os.path.join(postDir, 'content.md')
         fileHtml2 = os.path.join(postDir, 'content.html')
 
         with open(fileHtml2, "w") as ff:
-            with open(fileName, "w") as f:
+            with open(fileMarkDown, "w") as f:
                 f.write("{}\n".format(deliminator))
                 f.write("title: ")
                 f.write(title)
@@ -297,15 +303,20 @@ class Wordpress:
                 self.writeContent(ff, content, "html")
     
     def run(self, args):
-        p = os.environ.get('http_proxy')
-        if p is not None:
-            printDebug("DEBUG", "Using http_proxy evvironment variable")
-            if 'http://' in p :
-                p = p.replace('http://', '')
-            else:pass
-            self.wp = Client(self.blog, args.user, args.password, proxy=p)
+        p = args.proxy
+        if p is None:
+            p = os.environ.get('http_proxy')
+            if p is not None:
+                printDebug("DEBUG", "Using http_proxy evvironment variable")
+                if 'http://' in p :
+                    p = p.replace('http://', '')
+            else:
+                printDebug("DEBUG", "Not using proxy")
+                self.wp = Client(self.blog, args.user, args.password)
         else:
-            self.wp = Client(self.blog, args.user, args.password)
+            p = p.replace('http://', '')
+
+        self.wp = Client(self.blog, args.user, args.password, proxy=p)
         # Send a file to wordpress.
         if args.update :
             fileName = args.update
